@@ -44,13 +44,13 @@ int main(int argc, char *argv[])
                         KMESS_VERSION,                             // app version from config-kmess.h
                         ki18n("A Live Messenger client for KDE"),  // short description
                         KAboutData::License_GPL,                   // license
-                        ki18n("(c) 2002-2010, Mike K. Bennett\n"   // copyright
-                              "(c) 2005-2010, Diederik van der Boor\n"
-                              "(c) 2007-2010, Valerio Pilo\n"
-                              "(c) 2008-2010, Antonio Nastasi\n"
-                              "(c) 2008-2010, Ruben Vandamme\n"
-                              "(c) 2009-2010, Sjors Gielen\n"
-                              "(c) 2009-2010, Adam Goossens\n"),
+                        ki18n("(c) 2002-2012, Mike K. Bennett\n"   // copyright
+                              "(c) 2005-2012, Diederik van der Boor\n"
+                              "(c) 2007-2012, Valerio Pilo\n"
+                              "(c) 2008-2012, Antonio Nastasi\n"
+                              "(c) 2008-2012, Ruben Vandamme\n"
+                              "(c) 2009-2012, Sjors Gielen\n"
+                              "(c) 2009-2012, Adam Goossens\n"),
                         KLocalizedString(),
                         "http://www.kmess.org/",                   // home page
                         "bugs" "@" "kmess" "." "org"               // address for bugs
@@ -132,7 +132,7 @@ int main(int argc, char *argv[])
   aboutData.addCredit( ki18n("Vincenzo Reale"),            ki18n("More Italian translation"),        "smart2128" "@" "baslug" "." "org");
   aboutData.addCredit( ki18n("Andrea Decorte"),            ki18n("More Italian translation, Group selection in 'contact added user' dialog"), "adecorte" "@" "gmail" "." "com");
 
-  aboutData.addCredit( ki18n("Daniel E. Moctezuma"),       ki18n("Japanese translation"),            "shinsen27" "@" "gmail" "." "com");
+  aboutData.addCredit( ki18n("Daniel E. Moctezuma"),       ki18n("Japanese translation"),            "dmoctezuma" "@" "kmess" "." "org");
   aboutData.addCredit( ki18n("Park Dong Cheon"),           ki18n("Korean translation"),              "pdc" "@" "kaist" "." "ac.kr");
   aboutData.addCredit( ki18n("Øyvind Sæther"),             ki18n("Norsk Bokmål translation"),         "oyvind" "@" "sather" "." "tk");
 
