@@ -456,6 +456,7 @@ void HttpSoapConnection::slotRequestFinished( QNetworkReply *reply )
   const QByteArray& replyContents = reply->readAll();
   const int         statusCode    = reply->attribute( QNetworkRequest::HttpStatusCodeAttribute   ).toInt();
   const QString     error         ( reply->attribute( QNetworkRequest::HttpReasonPhraseAttribute ).toString() );
+  QUrl              redirectUrl   = reply->attribute( QNetworkRequest::RedirectionTargetAttribute ).toUrl();
 
 #ifdef KMESSDEBUG_HTTPSOAPCONNECTION_GENERAL
   bool requestSuccess = false;
@@ -490,13 +491,16 @@ void HttpSoapConnection::slotRequestFinished( QNetworkReply *reply )
 #endif
 
     // Parse the message contents
-    if( currentResponse->isFaultMessage() )
+    if( ! redirectUrl.isEmpty() || currentResponse->isFaultMessage() )
     {
-      // Verify if the server is redirecting us to another server
       if( currentResponse->getFaultCode() == "psf:Redirect" )
+      {
+        redirectUrl = XmlFunctions::getNodeValue( currentResponse->getFault(), "redirectUrl" );
+      }
+      // Verify if the server is redirecting us to another server
+      if( ! redirectUrl.isEmpty() )
       {
         const QUrl& originalUrl = currentResponse->getEndPoint();
-        const QUrl redirectUrl( XmlFunctions::getNodeValue( currentResponse->getFault(), "redirectUrl" ) );
         const QString originalHost( originalUrl.host() );
         const QString redirectHost( redirectUrl.host() );
 
