@@ -20,6 +20,7 @@
 #include "../utils/kmessconfig.h"
 #include "../kmessdebug.h"
 #include "accountsmanagerpage.h"
+#include "filetransfersettingspage.h"
 #include "miscellaneouspage.h"
 
 #include <QCloseEvent>
@@ -49,6 +50,7 @@ GlobalSettingsDialog::GlobalSettingsDialog( QWidget *parent )
 
   // Create the widgets that belong in the pages
   accountsManagerPage_ = new AccountsManagerPage();
+  fileTransferSettingsPage_ = new FileTransferSettingsPage();
   miscellaneousPage_ = new MiscellaneousPage();
   notificationPage_ = new KNotifyConfigWidget( this );
   notificationPage_->setApplication( "kmess" );
@@ -70,6 +72,10 @@ GlobalSettingsDialog::GlobalSettingsDialog( QWidget *parent )
   page->setHeader( i18n( "Settings" ) );
   page->setIcon( KIcon( "configure" ) );
 
+  page = addPage( fileTransferSettingsPage_, i18n( "FileTransfers" ) );
+  page->setIcon( KIcon( "folder-remote" ) );
+  page->setHeader( i18n( "Transfer Settings" ) );
+
   // Let all the tabs load their settings
   loadSettings();
 }
@@ -120,6 +126,7 @@ void GlobalSettingsDialog::loadSettings()
   const KConfigGroup group( KMessConfig::instance()->getGlobalConfig( "General" ) );
 
   miscellaneousPage_->loadSettings( group );
+  fileTransferSettingsPage_->loadSettings( group );
 }
 
 
@@ -134,6 +141,11 @@ bool GlobalSettingsDialog::saveSettings()
     return false;
   }
 
+  if( !fileTransferSettingsPage_->saveSettings( group ) )
+  {
+      return false;
+  }
+
   notificationPage_ ->save();
 
   // Force the saving to be sure the KMessShared Class gets the correct options
